function [data]=doubletime(data)
%DOUBLETIME    Makes SAC data have double precision timing
%
%     Cleans up the delta and e header values by eliminating
%     the larger error in timing from a single precision
%     delta value.
%
%    Usage:  [data]=doubletime(data)
%
%    by Garrett Euler (10/2007)   ggeuler@wustl.edu
%
%    See also: ch, gh

% check nargin
error(nargchk(1,1,nargin))

% check data structure
if(~isstruct(data))
    error('sac data is not a structure')
elseif(~isfield(data,'name') || ~isfield(data,'head'))
    error('sac data structure does not have proper fields')
end 

% get necessary timing info
[delta,b,npts]=gh(data,'delta','b','npts');

% clean delta (remove any nonzero digits more than 6 places beyond decimal)
delta=round(delta*10^6)/10^6;

% new end value
e=b+(npts-1).*delta;

% change delta and end
data=ch(data,'delta',delta,'e',e);

end