function [data]=rdrift(data)
%RDRIFT    Romoves the data trend and mean 
%          from SAC data
%
%    Usage:  [data]=rdrift(data)
%
%    by Garrett Euler (10/2007)   ggeuler@wustl.edu
%
%    See also: rmean, rtrend, sactaper

% check input
error(nargchk(1,1,nargin))

% check data structure
if(~isstruct(data))
    error('sac data is not a structure')
elseif(~isfield(data,'name') || ~isfield(data,'head') || ~isfield(data,'amp'))
    error('sac data structure does not have proper fields')
end

% remove trend from each file
for i=1:length(data)
    % remove the trend
    data(i).amp=detrend(data(i).amp);
    
    % adjust header
    data(i)=ch(data(i),'depmen',mean(data(i).amp),...
        'depmin',min(data(i).amp),'depmax',max(data(i).amp));
end

end
