function [data]=rmean(data)
%RMEAN    Romoves the data mean from SAC data
%
%    Usage:  [data]=rmean(data)
%
%    by Garrett Euler (10/2007)   ggeuler@wustl.edu
%
%    See also: rtrend, rdrift, sactaper

% check input
error(nargchk(1,1,nargin))

% check data structure
if(~isstruct(data))
    error('sac data is not a structure')
elseif(~isfield(data,'name') || ~isfield(data,'head') || ~isfield(data,'amp'))
    error('sac data structure does not have proper fields')
end 

% remove mean from each file
for i=1:length(data)
    data(i).amp=data(i).amp-mean(data(i).amp);
    
    % adjust header
    data(i)=ch(data(i),'depmen',mean(data(i).amp),...
        'depmin',min(data(i).amp),'depmax',max(data(i).amp));
end

end
