function [data]=rtrend(data)
%RTREND    Romoves the data trend from SAC data
%    Note: The mean of the data is preserved.
%
%    Usage:  [data]=rtrend(data)
%
%    by Garrett Euler (10/2007)   ggeuler@wustl.edu
%
%    See also: rmean, rdrift, sactaper

% check input
error(nargchk(1,1,nargin))

% check data structure
if(~isstruct(data))
    error('sac data is not a structure')
elseif(~isfield(data,'name') || ~isfield(data,'head') || ~isfield(data,'amp'))
    error('sac data structure does not have proper fields')
end

% grab timing info
[b,delta,npts,leven]=gh(data,'b','delta','npts','leven');

% remove trend from each file
for i=1:length(data)
    % get the mean of the data
    m=mean(data(i).amp);
    
    % make timing vector
    if(leven(i))
        times=b(i)+(0:npts(i)-1)'*delta(i);
    else
        times=data(i).time;
    end
    
    % fit the data
    p=polyfit(times,data(i).amp,1);
    
    % remove the trend
    data(i).amp=data(i).amp-polyval(p,times);
    
    % add in the mean
    data(i).amp=data(i).amp+m;
    
    % adjust header
    data(i)=ch(data(i),'depmen',mean(data(i).amp),...
        'depmin',min(data(i).amp),'depmax',max(data(i).amp));
end

end
