function []=xsacfilterdir(dir_in,dir_out,type,style,limits,order,passes,ripple)
%XSACFILTERDIR    Read, Resample, and Write SAC binary files.
%    Reads in SAC (seismic analysis code) binary data
%    using 'rsac', resamples using 'sacsample',
%    and finally writes sac binary with 'wsac'. 
%
%    Intended to be an external script run via 
%    'matlab -r xsacfilterdir(...)' on the command line.
%
%    Escape characters will be needed for running from 
%    the command line.
%
%    Usage: xsacfilterdir('dir_in','dir_out',type,style,limits,order,passes,ripple)
%
%    Examples:
%
%     impliment a highpass elliptical filter with a passband
%     corner at 0.1 Hz on a directory of data via bash
%    matlab -nosplash -nojvm -r xsacfilterdir\(\'data-dir1\'\,\'data-dir2\'\,\'ellip\'\,\'high\',\[0.1\]\)\;exit\;  
%
%    by Garrett Euler (10/2007)   ggeuler@wustl.edu
%
%    See also: sacfilter, rsac, wsac, gh

% check number of arguments
error(nargchk(5,8,nargin))

% get file list
files=dir(dir_in);

% move into data dir
cwd=cd;
cd(dir_in);

% read in sac file
[data]=rsac(files(~[files.isdir]).name);

% resample
if(nargin==5)
    [data]=sacfilter(data,type,style,limits);
elseif(nargin==6)
    [data]=sacfilter(data,type,style,limits,order);
elseif(nargin==7)
    [data]=sacfilter(data,type,style,limits,order,passes);
else
    [data]=sacfilter(data,type,style,limits,order,passes,ripple);
end

% move into new dir
cd(cwd);
cd(dir_out);

% write out
wsac(data);

end