function []=xsacsampledir(dir_in,dir_out,dt)
%XSACSAMPLEDIR    Read, Resample, and Write SAC binary files.
%    Reads in SAC (seismic analysis code) binary data
%    using 'rsac', resamples using 'sacsample',
%    and finally writes sac binary with 'wsac'. 
%
%    Intended to be an external script run via 
%    'matlab -r xsacsampledir(...)' on the command line.
%
%    Escape characters will be needed for running from 
%    the command line.
%
%    Usage: xsacsampledir('dir_in','dir_out',delta)
%
%    Examples:
%
%     resample a directory of data to 5 sps via bash:
%    matlab -nosplash -nojvm -r xsacsampledir\(\'data-dir1\'\,\'data-dir2\'\,0.2\)\;exit\;  
%
%    by Garrett Euler (10/2007)   ggeuler@wustl.edu
%
%    See also: sacsample, rsac, wsac, gh

% check number of arguments
error(nargchk(3,3,nargin))

% get file list
files=dir(dir_in);

% move into data directory
cwd=cd;
cd(dir_in);

% read in sac file
[data]=rsac(files(~[files.isdir]).name);

% resample
[data]=sacsample(data,dt);

% move into new dir
cd(cwd);
cd(dir_out);

% write out
wsac(data);

end